# ToR Auto Done Replier

**This is an UNOFFICIAL program and is not officially endorsed by the Transcribers of Reddit; they are in no way involved with this program and are not liable for any matters relating to it. This is developed unofficially, in my capacity as a volunteer, NOT a moderator.**

Also known as TADR, this program monitors the Reddit inbox of its user and detects comment from the r/TranscribersOfReddit bot notifying them that it could not find their transcription. Upon receiving such a message, ADR checks the parent comment of the message. If that comment is "done", TADR will reply to it with its own automated response, triggering it to look for the transcription again. If the parent comment is TADR's automated reply, it will send a desktop notification to the user to tell them that something is wrong.

TADR's documentation is hosted at readthedocs: https://tadr.readthedocs.io/en/latest/

For emergency contact, I'm reachable through `murdo@maclachlans.org.uk` and `murdomaclachlan@gmail.com` (the first address is preferred). You can also open an issue on GitHub if needed.
